==> knox-1.2.0-src.zip: knox-1.2.0/gateway-util-urltemplate/src/main/java/org/apache/knox/gateway/util/urltemplate/Query.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.knox.gateway.util.urltemplate;

public class Query extends Segment {

  private String queryName;

  public Query( String queryName, String paramName, String valuePattern, boolean literal ) {
    super( new Token( paramName, valuePattern, literal ) );
    this.queryName = queryName;
  }

  public Query( Query that ) {
    super( that.getToken() );
    this.queryName = that.queryName;
  }

  Query( String queryName, Token token ) {
    super( token );
    this.queryName = queryName;
  }

  public String getQueryName() {
    return queryName;
  }

  @Override
  public boolean matches( Segment that ) {
    boolean matches = super.matches( that );
    if( matches ) {
      Query thatQuery = (Query)that;
      matches = this.queryName.equals( thatQuery.queryName );
    }
    return matches;
  }

}

==> knox-2.1.0-src.zip: knox-2.1.0/gateway-util-urltemplate/src/main/java/org/apache/knox/gateway/util/urltemplate/Query.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.knox.gateway.util.urltemplate;

public class Query extends Segment {

  private String queryName;

  public Query( String queryName, String paramName, String valuePattern, boolean literal ) {
    super( new Token( paramName, valuePattern, literal ) );
    this.queryName = queryName;
  }

  public Query( Query that ) {
    super( that.getToken() );
    this.queryName = that.queryName;
  }

  Query( String queryName, Token token ) {
    super( token );
    this.queryName = queryName;
  }

  public String getQueryName() {
    return queryName;
  }

  @Override
  public boolean matches( Segment that ) {
    boolean matches = super.matches( that );
    if( matches ) {
      Query thatQuery = (Query)that;
      matches = this.queryName.equals( thatQuery.queryName );
    }
    return matches;
  }

  @Override
  public boolean equals(Object obj) {
    if( obj instanceof Query ) {
      Query that = (Query)obj;
      return super.equals(that) && that.getQueryName().equals(getQueryName());
    }
    return false;
  }

  @Override
  public int hashCode() {
    int result = super.hashCode();
    return 31 * result + getQueryName().hashCode();
  }
}
